@@ -1,6 +1,6 @@
 /*
 
- $Id: arch.cpp,v 1.22 2000/05/30 21:09:46 ezust Exp $
+ $Id: arch.cpp,v 1.30 2000/08/01 16:06:38 bieker Exp $
 
  ark -- archiver for the KDE project
 
@@ -26,12 +26,18 @@
 
 */
 
-#include <kdebug.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <stdlib.h>
 #include <time.h>
 
-#define ABS(x) (x) < 0? -(x) : (x)
+#include <qapplication.h>
+#include <qfile.h>
+
+#include <kdebug.h>
+#include <kmessagebox.h>
+#include <kmimemagic.h>
+#include <klocale.h>
+
+#include <stdlib.h>
 
 // ark includes
 #include "arch.h"
@@ -50,6 +56,23 @@ Arch::~Arch()
 {
 }
 
+void Arch::verifyUtilityIsAvailable(const QString & _utility1,
+			      const QString & _utility2)
+{
+  // see if the utility is in the PATH of the user. If there is a
+  // second utility specified, it must also be present.
+  QString cmd = "which " + _utility1;
+  int ret1 = system(QFile::encodeName(cmd));
+  int ret2 = 0;
+  if (!_utility2.isNull())
+    {
+      cmd = "which " + _utility2;
+      ret2 = system(QFile::encodeName(cmd));
+    }
+
+  m_bUtilityIsAvailable = ((ret1 == 0) && (ret2 == 0));
+}
+
 void Arch::slotCancel()
 {
   //  m_kp->kill();
@@ -113,6 +136,7 @@ void Arch::slotDeleteExited(KProcess *_kp)
     {
       if(stderrIsError())
 	{
+	  QApplication::restoreOverrideCursor();
 	  KMessageBox::error( 0, i18n("You probably don't have sufficient permissions.\n"
 				      "Please check the file owner and the integrity\n"
 				      "of the archive.") );
@@ -124,6 +148,7 @@ void Arch::slotDeleteExited(KProcess *_kp)
     {
       if (m_bNotifyWhenDeleteFails)
 	{
+	  QApplication::restoreOverrideCursor();
 	  KMessageBox::sorry( (QWidget *)0,
 			      i18n("Deletion failed"), i18n("Error") );
 	}
@@ -151,6 +176,7 @@ void Arch::slotExtractExited(KProcess *_kp)
     {
       if(stderrIsError())
 	{
+	  QApplication::restoreOverrideCursor();
 	  int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the extract operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
@@ -180,6 +206,7 @@ void Arch::slotAddExited(KProcess *_kp)
     {
       if(stderrIsError())
 	{
+	  QApplication::restoreOverrideCursor();
 	  KMessageBox::error( 0, i18n("You probably don't have sufficient permissions\n"
 				      "Please check the file owner and the integrity\n"
 				      "of the archive.") );
@@ -189,6 +216,7 @@ void Arch::slotAddExited(KProcess *_kp)
     }
   else
     {
+      QApplication::restoreOverrideCursor();
       int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the add operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
@@ -229,10 +257,10 @@ QString Utils::getTimeStamp(const QString &_month,
   // (five months' difference - e.g., if it's Apr, then get years up to Nov)
 
   char month[4];
-  strncpy(month, (const char *)_month, 3);
+  strncpy(month, _month.ascii(), 3);
   month[3] = '\0';
   int nMonth = getMonth(month);
-  int nDay = atoi((const char *)_day);
+  int nDay = _day.toInt();
 
   kdDebug(1601) << "Month is " << nMonth << ", Day is " << nDay << endl;
 
@@ -264,8 +292,8 @@ QString Utils::getTimeStamp(const QString &_month,
     
   QString retval;
   retval.sprintf("%s-%.2d-%.2d %s",
-		 (const char *)year, nMonth, nDay, 
-		 (const char *)timestamp);
+		 year.utf8().data(), nMonth, nDay, 
+		 timestamp.utf8().data());
   return retval;
 }
 
@@ -291,7 +319,7 @@ int Utils::getMonth(const char *strMonth)
 
 int Utils::getYear(int theMonth, int thisYear, int thisMonth)
 {
-  int monthDiff = ABS(thisMonth - theMonth);
+  int monthDiff = QABS(thisMonth - theMonth);
   if (monthDiff > 6)
     return (thisYear - 1);
   else
@@ -318,6 +346,98 @@ QString Utils::fixYear(const char *strYear)
   return fourDigits;
 }
 
+ArchType getArchType( const QString & archname, QString &extension)
+{
+  if ((archname.right(4) == ".tgz") || (archname.right(4) == ".tzo")
+       || (archname.right(4) == ".taz")
+       || (archname.right(4) == ".tar"))
+    {
+      extension = archname.right(4);
+      return TAR_FORMAT;      
+    }
+  if (archname.right(6) == ".tar.Z")
+    {
+      extension = ".tar.Z";
+      return TAR_FORMAT;
+    }
+  if ((archname.right(7) == ".tar.gz")
+      || (archname.right(7) == ".tar.bz"))
+    {
+      extension = archname.right(7);
+      return TAR_FORMAT;
+    }
+  if ((archname.right(8) == ".tar.bz2")
+      || (archname.right(8) == ".tar.lzo"))
+    {
+      extension = archname.right(8);
+      return TAR_FORMAT;
+    }
+  if ((archname.right(4) == ".lha") || (archname.right(4) == ".lzh"))
+    {
+      extension = archname.right(4);
+      return LHA_FORMAT;
+    }
+  if ((archname.right(4) == ".zip") || (archname.right(4) == ".xpi"))
+    {
+      extension = archname.right(4);
+      return ZIP_FORMAT;
+    }
+  if ((archname.right(3) == ".gz") || (archname.right(3) == ".bz"))
+    {
+      extension = archname.right(3);
+      return COMPRESSED_FORMAT;
+    }
+  if ((archname.right(4) == ".bz2") || (archname.right(4) == ".lzo"))
+    {
+      extension = archname.right(4);
+      return COMPRESSED_FORMAT;
+    }
+  if (archname.right(2) == ".Z")
+    {
+      extension = ".Z";
+      return COMPRESSED_FORMAT;
+    }
+  if (archname.right(4) == ".zoo")
+    {
+      extension = ".zoo";
+      return ZOO_FORMAT;
+    }
+  if (archname.right(4) == ".rar")
+    {
+      extension = ".rar";
+      return RAR_FORMAT;
+    }
+  if (archname.right(2) == ".a")
+    {
+      extension = ".a";
+      return AA_FORMAT;
+    }
+
+  // now try using magic
+  
+  KMimeMagic *mimePtr = KMimeMagic::self();
+  KMimeMagicResult * mimeResultPtr = mimePtr->findFileType(archname);
+  QString mimetype = mimeResultPtr->mimeType();
+  extension = QString::null;
+
+  kdDebug(1601) << "The mime type is " << mimetype << endl;
+
+  if (mimetype == "application/x-rar")
+    return RAR_FORMAT;
+  if (mimetype == "application/x-lha")
+    return LHA_FORMAT;
+  if (mimetype == "application/x-archive")
+    return AA_FORMAT;
+  if (mimetype == "application/x-tar")
+    return TAR_FORMAT;
+  if (mimetype == "application/x-zip")
+    return ZIP_FORMAT;
+
+  return UNKNOWN_FORMAT;
+}
+
+
+
 #include "arch.moc"
 
 
