@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: rar.h,v 1.5 2000/05/16 18:52:14 ezust Exp $
+ $Id: rar.h,v 1.6 2000/06/13 20:34:44 ezust Exp $
 
  ark -- archiver for the KDE project
 
@@ -57,9 +57,6 @@ protected slots:
   //  void slotExtractDone(KProcess *_);
 
 private: // data
-  QString m_archiver_program;
-  QString m_unarchiver_program;
-
   int m_linenumber;
   QString m_line1, m_line2; // for keeping till we have all three lines
 
