@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zip.h,v 1.22 2000/05/16 18:52:14 ezust Exp $
+ $Id: zip.h,v 1.23 2000/06/13 20:34:44 ezust Exp $
 
   ark -- archiver for the KDE project
 
@@ -59,7 +59,7 @@ public:
   virtual void unarchFile(QStringList *, const QString & _destDir="");
 	
   void testIntegrity();
-	
+
   enum AddMode { Update = 1, Freshen, Move };
 
 protected:
@@ -70,8 +70,6 @@ protected slots:
   void slotReceivedTOC(KProcess *, char *, int);
 	
 private:
-  QString m_archiver_program;
-  QString m_unarchiver_program;
   void processLine( char* );	
   void setHeaders();
 };
