@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Revision: 1.13 $	 
+   $Revision: 1.14.2.1 $	 
 */
 
 #include <kapp.h>
@@ -28,7 +28,7 @@
 static const char *description = 
 	I18N_NOOP("KDE Addressbook");
 
-static const char *version = "v2.0pre";
+static const char *version = "v2.0";
 
 int main(int argc, char** argv)
 {
@@ -54,8 +54,6 @@ int main(int argc, char** argv)
   app.setMainWidget(widget);
   widget->show();
   rc=app.exec();
-  // delete widget;
-  widget->destroyMe();
   return rc;
 }
 
