@@ -30,7 +30,7 @@
 #include <qpopupmenu.h>
 #include <qtooltip.h>
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 #include "disklist.h"
 #include "kdfconfig.h"
@@ -67,7 +67,7 @@ class MyPopupMenu : public QPopupMenu
     MyPopupMenu(QWidget *parent=0, const char *name=0);
     ~MyPopupMenu( void );
 
-    void setToolTip(int id, const QString *text );
+    void setToolTip(int id, const QString & text );
     QRect itemRectangle( int id );
     int activeIndex( void );
 
@@ -128,7 +128,7 @@ class DockWidget : public QLabel
 
 
 /***************************************************************/
-class KwikDiskTopLevel : public KTMainWindow
+class KwikDiskTopLevel : public KMainWindow
 { 
   Q_OBJECT
 
