@@ -334,7 +334,7 @@ class CInsertDialog : public KDialogBase
 void centerDialog( QWidget *widget, QWidget *centerParent );
 void centerDialogBottom( QWidget *widget, QWidget *centerParent );
 void comboMatchText( QComboBox *combo, const QString &text );
-bool stringToOffset( const char *text, uint &offset );
+bool stringToOffset( const QString & text, uint &offset );
 
 void showEntryFailure( QWidget *parent, const QString &msg );
 bool verifyFileDestnation( QWidget *parent, const QString &title, 
