@@ -31,7 +31,6 @@ extern "C" {
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlistbox.h>
-#include <qlistview.h>
 #include <qpushbutton.h>
 #include <qkeycode.h>
 #include <qcollection.h>
@@ -40,13 +39,19 @@ extern "C" {
 #include <qcursor.h>
 #include <qevent.h>
 #include <qdragobject.h>
+#include <qlayout.h>
+#include <qaccel.h>
 
+#include <klistview.h>
+#include <kglobal.h>
+#include <kdebug.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kmenubar.h>
 #include <kstdaccel.h>
+#include <kio/netaccess.h>
 
 #include "klpq.h"
 #include "klpq.moc"
@@ -55,13 +60,13 @@ extern "C" {
 #include "FirstStart.h"
 
 Klpq::Klpq( const char *name )
-  : KTMainWindow( name )
+  : KMainWindow( 0, name )
 {
   update_delay = 0; // means no auto update at all
-  KConfig *config = KApplication::kApplication()->config();
-  config->setGroup("klpq");
-  if( config->hasKey("updateDelay") )
-    update_delay = config->readNumEntry("updateDelay");
+  KConfig *config = KGlobal::config();
+  config->setGroup( QString::fromLatin1("klpq") );
+  if( config->hasKey( QString::fromLatin1("updateDelay") ) )
+    update_delay = config->readNumEntry( QString::fromLatin1("updateDelay") );
 
   conf_auto = new ConfAutoUpdate( topLevelWidget(), "update" );
   conf_auto->setFrequency(update_delay);
@@ -94,12 +99,17 @@ Klpq::Klpq( const char *name )
   c_printing->setText( i18n("Printing") );
   hlayout->addWidget( c_printing, 1 );
 
-  lb_list = new QListView(f_main);
+  lb_list = new KListView(f_main);
+  lb_list->setSelectionMode( QListView::Extended );
+
   lb_list->addColumn(i18n("Rank"), 75);
+  lb_list->setColumnAlignment( 0, AlignRight );
   lb_list->addColumn(i18n("Owner"), 150);
   lb_list->addColumn(i18n("Job"), 75);
+  lb_list->setColumnAlignment( 2, AlignRight );
   lb_list->addColumn(i18n("Files"), 150);
   lb_list->addColumn(i18n("Size"), 75);
+  lb_list->setColumnAlignment( 4, AlignRight );
 
   //  connect( lb_list, SIGNAL(rightButtonClicked()), this, SLOT(popupMenu()) );
 
@@ -142,23 +152,23 @@ Klpq::Klpq( const char *name )
   file->insertItem(i18n("&Quit"), qApp, SLOT(quit()), KStdAccel::key(KStdAccel::Quit) );
 
   QPopupMenu *conf_menu = new QPopupMenu;
-  conf_menu->insertItem(i18n("&Update frequency"),this,SLOT(configureAuto()));
-  conf_menu->insertItem(i18n("&Spooler"), this, SLOT(configureSpooler()) );
+  conf_menu->insertItem(i18n("&Update frequency..."),
+			this, SLOT(configureAuto()));
+  conf_menu->insertItem(i18n("&Spooler..."), this,
+			SLOT(configureSpooler()) );
 
-  QString about = i18n(""
-    "Klpq %1\n(C) by Christoph Neerfeld\nchris@kde.org").arg(KLPQ_VERSION);
   menuBar()->insertItem( i18n("&File"), file );
   menuBar()->insertItem( i18n("&Options"), conf_menu );
   menuBar()->insertSeparator();
-  menuBar()->insertItem( i18n("&Help"), helpMenu( about ) );
+  menuBar()->insertItem( i18n("&Help"),	helpMenu( ) );
 
-  connect( cb_printer, SIGNAL(activated(int)), this, SLOT(printerSelect(int)));
-  connect( c_queuing, SIGNAL(clicked()), this, SLOT(queuing()) );
-  connect( c_printing, SIGNAL(clicked()), this, SLOT(printing()) );
-  connect( b_update, SIGNAL(clicked()), this, SLOT(update()) );
-  connect( b_remove, SIGNAL(clicked()), this, SLOT(remove()) );
-  connect( b_make_top, SIGNAL(clicked()), this, SLOT(makeTop()) );
-  connect( b_auto, SIGNAL(clicked()), this, SLOT(setAuto()) );
+  connect( cb_printer, SIGNAL(activated(int)), SLOT(printerSelect(int)));
+  connect( c_queuing, SIGNAL(clicked()), SLOT(queuing()) );
+  connect( c_printing, SIGNAL(clicked()), SLOT(printing()) );
+  connect( b_update, SIGNAL(clicked()), SLOT(update()) );
+  connect( b_remove, SIGNAL(clicked()), SLOT(remove()) );
+  connect( b_make_top, SIGNAL(clicked()), SLOT(makeTop()) );
+  connect( b_auto, SIGNAL(clicked()), SLOT(setAuto()) );
 
   popup_menu = new QPopupMenu;
   popup_menu->insertItem( i18n("Remove"), this, SLOT(remove()) );
@@ -167,35 +177,33 @@ Klpq::Klpq( const char *name )
   int key_id;
   accel = new QAccel(this);
   accel->connectItem( accel->insertItem( Key_U ), this, SLOT(update()) );
-  accel->connectItem( accel->insertItem( Key_R ), this, SLOT(remove()) );
+  accel->connectItem( accel->insertItem( Key_Delete ), this, SLOT(remove()) );
   accel->connectItem( accel->insertItem( Key_T ), this, SLOT(makeTop()) );
   key_id = accel->insertItem( Key_A );
   accel->connectItem( key_id, b_auto, SLOT(toggle()) );
   accel->connectItem( key_id, this, SLOT(setAuto()) );
   accel->connectItem( accel->insertItem( Key_Left ), this, SLOT(prevPrinter()) );
   accel->connectItem( accel->insertItem( Key_Right ), this, SLOT(nextPrinter()) );
-  //accel->connectItem( accel->insertItem( Key_E ), this, SLOT(queuing()) );
-  //accel->connectItem( accel->insertItem( Key_I ), this, SLOT(printing()) );
 
-  setView(f_main, FALSE);
+  setCentralWidget(f_main);
 
   // set up subprocess
-  QString temp;
   FirstStart spooler_dialog;
-  if( (temp = config->readEntry("Spooler") ) == "BSD" )
+  QString temp = config->readEntry( QString::fromLatin1("Spooler") );
+  if ( temp == QString::fromLatin1("BSD") )
     spooler = new SpoolerBsd;
-  else if( temp == "PPR" )
+  else if( temp == QString::fromLatin1("PPR") )
     spooler = new SpoolerPpr;
-  else if ( temp == "LPRNG" )
+  else if ( temp == QString::fromLatin1("LPRNG") )
     spooler = new SpoolerLprng;
   else
     {
       spooler_dialog.exec();
       temp = spooler_dialog.getSpooler();
-      config->writeEntry("Spooler", temp);
-      if( temp == "PPR" )
+      config->writeEntry(QString::fromLatin1("Spooler"), temp);
+      if( temp == QString::fromLatin1("PPR") )
 	spooler = new SpoolerPpr;
-      else if ( temp == "LPRNG" )
+      else if ( temp == QString::fromLatin1("LPRNG") )
 	spooler = new SpoolerLprng;
       else
 	spooler = new SpoolerBsd;
@@ -218,17 +226,12 @@ Klpq::Klpq( const char *name )
   setAcceptDrops(true);
 
   int width, height;
-  config->setGroup("klpq");
-  width = config->readNumEntry("Width");
-  height = config->readNumEntry("Height");
-  if( width < minimumSize().width() )
-    width = minimumSize().width();
-  if( height < minimumSize().height() )
-    height = minimumSize().height();
+  config->setGroup(QString::fromLatin1("klpq"));
+  width = config->readNumEntry(QString::fromLatin1("Width"), sizeHint().width());
+  height = config->readNumEntry(QString::fromLatin1("Height"), sizeHint().height());
+  resize( width, height );
 
-  resize(f_main->sizeHint());
-
-  b_auto->setOn( config->readBoolEntry("autoOn", TRUE) );
+  b_auto->setOn( config->readBoolEntry(QString::fromLatin1("autoOn"), TRUE) );
   setAuto();
 }
 
@@ -240,18 +243,17 @@ Klpq::~Klpq()
   delete lpc;
   delete lpq;
 
-  KConfig &config = *kapp->config();
-  config.setGroup("klpq");
-  config.writeEntry("Width", width());
-  config.writeEntry("Height", height());
-  config.writeEntry("updateDelay", update_delay);
-  config.writeEntry("autoOn", b_auto->isOn() );
-  config.writeEntry("lastQueue", cb_printer->currentText() );
+  KConfig &config = *KGlobal::config();
+  config.setGroup(QString::fromLatin1("klpq"));
+  config.writeEntry(QString::fromLatin1("Width"), width());
+  config.writeEntry(QString::fromLatin1("Height"), height());
+  config.writeEntry(QString::fromLatin1("updateDelay"), update_delay);
+  config.writeEntry(QString::fromLatin1("autoOn"), b_auto->isOn() );
+  config.writeEntry(QString::fromLatin1("lastQueue"),
+		    cb_printer->currentText() );
   config.sync();
 }
 
-
-
 void Klpq::setLastPrinterCurrent()
 {
   if( cb_printer->count() )
@@ -312,43 +314,71 @@ void Klpq::printing()
 
 void Klpq::remove()
 {
-  if( !isEnabled() )
-    return;
-  int job = ((MyLVI *)lb_list->selectedItem())->jobId();
-  QString word;
-  word.setNum(job);
+  QList<int> list;
+
+  QListViewItem *it = lb_list->firstChild();
+  for (; it; it = it->itemBelow() )
+    if ( it->isSelected() )
+      list.append( new int( ((MyLVI *)it)->jobId() ) );
+
+  if (list.isEmpty()) return;
+
   QString ask;
-  ask = i18n("Do you really want to remove job No %1?").arg(job);
-  if( KMessageBox::questionYesNo(this, ask) == KMessageBox::Yes)
+  if (list.count() == 1)
+    ask = i18n("Do you really want to remove job No %1?")
+    .arg(KGlobal::locale()->formatNumber(*list.first(), 0));
+  else
+    ask = i18n("Do you really want to remove the marked jobs?");
+
+  if( KMessageBox::questionYesNo(this, ask) == KMessageBox::Yes )
     {
-      QString progname;
-      progname = spooler->removeCommand( cb_printer->text( cb_printer->currentItem() ), word );
-      system( progname );
+      for ( QListIterator<int> it(list); it.current(); ++it )
+	{
+	  KProcess proc;
+	  QStringList list = spooler->removeCommand
+	    ( cb_printer->text( cb_printer->currentItem() ),
+	      QString::number( *it.current() ) );
+	  for ( QStringList::Iterator it = list.begin();
+		it != list.end();
+		++it )
+	    proc << *it;
+
+	  proc.start(KProcess::Block);
+	}
+
       update();
     }
 }
 
 void Klpq::makeTop()
 {
-  if( !isEnabled() )
-    return;
-  int job = ((MyLVI *)lb_list->selectedItem())->jobId();
-  QString word;
-  word.setNum(job);
+  QList<int> list;
 
-  QString msg = i18n(""
-    "Do you really want to move job No %1\non top of queue?").arg(job);
-  if( KMessageBox::questionYesNo( this, msg ) == KMessageBox::Yes )
-  {
-    lpc->clearArguments();
-    spooler->makeTopCommand( lpc, cb_printer->text(cb_printer->currentItem()),
-			     word );
-    if( lpc->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
+  QListViewItem *it = lb_list->firstChild();
+  for (; it; it = it->itemBelow() )
+    if ( it->isSelected() )
+      list.append( new int( ((MyLVI *)it)->jobId() ) );
+
+  if (list.isEmpty()) return;
+
+  QString ask;
+  if (list.count() == 1)
+    ask = i18n("Do you really want to move job No %1\nto top of queue?")
+    .arg(KGlobal::locale()->formatNumber(*list.first(), 0));
+  else
+    ask = i18n("Do you really want to move the marked\njobs to top of queue?");
+
+  if( KMessageBox::questionYesNo(this, ask) == KMessageBox::Yes)
     {
-      lpc_com = MakeTop;
-      disable();
+      lpc->clearArguments();
+      spooler->makeTopCommand( lpc, cb_printer->text(cb_printer->currentItem()), list );
+      
+      if( lpc->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
+	{
+	  lpc_com = MakeTop;
+	  disable();
+	}
     }
-  }
 }
 
 void Klpq::setAuto()
@@ -403,34 +433,31 @@ void Klpq::configureAuto()
 
 void Klpq::configureSpooler()
 {
-  KConfig &config = *kapp->config();
-  config.setGroup("klpq");
-  conf_spooler->initConfig( config.readEntry("Spooler", "BSD") );
+  KConfig &config = *KGlobal::config();
+  config.setGroup(QString::fromLatin1("klpq"));
+  conf_spooler->initConfig( config.readEntry(QString::fromLatin1("Spooler"),
+					     QString::fromLatin1("BSD")) );
   if( conf_spooler->exec() )
   {
     QString spoolerName = conf_spooler->saveConfig();
     delete spooler;
-    if( spoolerName == "BSD" )
+    if( spoolerName == QString::fromLatin1("BSD") )
       spooler = new SpoolerBsd;
-    else if( spoolerName == "PPR" )
+    else if( spoolerName == QString::fromLatin1("PPR") )
       spooler = new SpoolerPpr;
-    else if ( spoolerName == "LPRNG" )
+    else if ( spoolerName == QString::fromLatin1("LPRNG") )
       spooler = new SpoolerLprng;
   }
 }
 
 void Klpq::enable()
 {
-  if( lpc_com != NotRunning || lpq_running )
-    return;
-  setEnabled(TRUE);
   QApplication::restoreOverrideCursor();
 }
 
 void Klpq::disable()
 {
   QApplication::setOverrideCursor( waitCursor );
-  setEnabled(FALSE);
 }
 
 void Klpq::updateList()
@@ -467,7 +494,7 @@ void Klpq::recvLpq( KProcess *, char *buffer, int len )
 {
   if( !lpq_running )
     {
-      debug("lpq not running");
+      kdDebug() << "lpq not running" << endl;
       return;
     }
   int i;
@@ -484,7 +511,7 @@ void Klpq::recvLpc( KProcess *, char *buffer, int len )
   QString temp;
   switch(lpc_com) {
   case NotRunning:
-    debug("lpc not running");
+    kdDebug() << "lpc not running" << endl;
     return;
   case Status:
     spooler->parseStatus( buffer, len, c_queuing, c_printing );
@@ -510,7 +537,8 @@ void Klpq::recvLpc( KProcess *, char *buffer, int len )
 	  temp += c;
 	else
 	  {
-	    if(temp.contains("Privileged") || temp.contains("permission") )
+	    if(temp.contains(QString::fromLatin1("Privileged")) ||
+	       temp.contains(QString::fromLatin1("permission")) )
 	      {
 		KMessageBox::error( this,
 				      i18n("This is a privileged command\n"
@@ -541,106 +569,57 @@ void Klpq::exitedLpc(KProcess *)
 
 void Klpq::dragEnterEvent(QDragEnterEvent* event)
 {
-  event->accept(QUrlDrag::canDecode(event));
+  event->accept(QUriDrag::canDecode(event));
 }
 
 
 void Klpq::dropEvent(QDropEvent* event)
 {
-  QString name;
   QStrList urls;
 
-  if(!QUrlDrag::decode(event, urls))
+  if(!QUriDrag::decode(event, urls))
     return;
 
-  QStrListIterator it(urls);
+  bool err = false;
+  for ( QStrListIterator it(urls); it.current(); ++it )
+  {
+    if (!printURL(*it, cb_printer->text( cb_printer->currentItem() )))
+      err = true;
+    update();
+  }
 
-  for( ; it.current(); ++it )
-    {
-      name = (QString) it.current();
-      if( name.left(5) != "file:" )
-	{
-	  remote_files.append( (QString) cb_printer->text(cb_printer->currentItem()) + ":" + name);
-	}
-      else
-	{
-	  name = name.remove(0,5);
-	  QString progname;
-	  progname = (QString) "lpr -P " + cb_printer->text( cb_printer->currentItem() ) + " "
-	    + name;
-	  system( (const char *) progname);
-	}
-    }
-  update();
-  if( remote_files.count() )
-    {
-      // start download of files
-      QString pid, current_file;
-      pid.setNum(::getpid());
-      current_file = "file:/tmp/klpq_download.";
-      current_file += pid;
-      QString temp = remote_files.first();
-      temp = temp.remove(0, temp.find(':')+1);
-      KIO::Job* iojob = KIO::copy(temp, current_file);
-//      iojob->setGUImode ( KIOJob::NONE );
-      connect( iojob, SIGNAL( result(KIO::Job *) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
-    }
+  if (err) messageNotFound();
 }
 
-void Klpq::slotIOJobFinished( KIO::Job* )
+void Klpq::messageNotFound()
 {
-  QString pid, current_file;
-  pid.setNum(::getpid());
-  current_file = "/tmp/klpq_download.";
-  current_file += pid;
-  QString queue = remote_files.first();
-  QFileInfo fi(current_file);
-  if( fi.exists() )
-    {
-      queue = queue.left( queue.find(':') );
-      QString progname;
-      if( queue.isEmpty() )
-	progname = (QString) "lpr " + current_file;
-      else
-	progname = (QString) "lpr -P " + queue + " " + current_file;
-      system( (const char *) progname);
-      QDir dir("/tmp");
-      dir.remove(current_file);
-    }
-  remote_files.removeFirst();
-  if( remote_files.count() != 0 )
-    {
-      QString temp = remote_files.first();
-      temp = temp.remove(0, temp.find(':')+1);
-      KIO::Job* iojob = KIO::copy(temp, "file:" + current_file);
-      connect( iojob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
-    }
-  else
-    {
-      if( !isVisibleToTLW() )
-	QApplication::exit();
-      QTimer::singleShot( 2000, this, SLOT(update()) );
-    }
+    KMessageBox::error(0, i18n("<qt>Could not print some of the files. "
+				  "Please make sure you have access to all "
+				  "files and that they are not "
+				  "directories.</qt>"));
 }
 
-void Klpq::printRemote( QStrList file_list )
+bool Klpq::printURL(const KURL &url, const QString &printer)
 {
-  remote_files = file_list;
-  QString pid, current_file;
-  pid.setNum(::getpid());
-  current_file = "file:/tmp/klpq_download.";
-  current_file += pid;
-  QString temp = remote_files.first();
-  temp = temp.remove(0, temp.find(':')+1);
-  KIO::Job * iojob = KIO::copy(temp, current_file);
-  connect( iojob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
+  QString target;
+  KIO::NetAccess::download(url, target);
+
+  KProcess proc;
+  proc << QString::fromLatin1("lpr");
+  if (!printer.isEmpty())
+  {
+    proc << QString::fromLatin1("-P");
+    proc << printer;
+  }
+  proc << target;
+  proc.start(KProcess::Block);
+
+  KIO::NetAccess::removeTempFile(target);
+
+  return proc.normalExit() && proc.exitStatus() == 0;
 }
 
 void Klpq::popupMenu()
 {
   popup_menu->popup(QCursor::pos());
 }
-
-
-
-
